tingyun_flutter_plugin library

Classes

Configuration
Configuration class which can be used for manual instrumentation.
Tingyun
TingyunAction
Tingyun Action which has a start- and end-time and can report several values onto it. When finished call leaveAction.
TingyunMaterialPageRoute<T>
TingyunRootAction
TYNavigatorObserver
TYWebRequestTiming
The Web request timing interface which can be used to measure a web request manually

Enums

LogLevel
Loglevel for the internal logs but it is used for the startup method as well.
WebMetricType