TingyunAction class abstract

Tingyun Action which has a start- and end-time and can report several values onto it. When finished call leaveAction.

Implementers

Constructors

TingyunAction()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createWebRequestTiming(String url) Future<TYWebRequestTiming>
Returns a Webrequest timing object which can be used to measure a web request. Input the url of the web request.
getRequestTag(String url) Future<String>
Returns a unique x-tingyun header for the web request with a specified url.
getRequestTagHeader() String
Returns the header key that needs to be added to the web request for user action/purepath correlation.
leaveAction({Map<String, dynamic>? props, int type = 0, String tag = ""}) → void
Leaves this Action. type:1 :page的leave的数据
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited