TYWebRequestTiming class abstract
The Web request timing interface which can be used to measure a web request manually
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRequestTag(
) → String - Returns the content for the header that is needed in order to track a request
-
getRequestTagHeader(
) → String - Returns the name for the header that is needed in order to track a request
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retriveTingyunResponseHeader(
) → Future< List< String> ?> -
start(
) → void - Start the measurment of the web request. Call this before the request is started.
-
stop(
int responseCode, {Map< String, String> retriveResponseHeader = const {}, Map<String, String> requestHeader = const {}, Map<String, String> apmExistInfo = const {}, Map<String, String> apmNotExistHeader = const {}, String requestBody = ""}) → void -
The
responseCodeandresponseMessagewill be transfered and shown in the web UI. -
toString(
) → String -
A string representation of this object.
inherited
-
withDnsInfo(
int dnsTime, String ipInfo) → void - set the dns info
-
withMetric(
WebMetricType type, dynamic value) → void - set the metric info
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited